@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1744 2025/09/10 23:19:13 daniel Exp $
+# $OpenBSD: Quirks.pm,v 1.1745 2025/09/13 12:45:20 kn Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -1286,6 +1286,7 @@ setup_obsolete_reason(
 	5 => 'clutter-gst',
 	3 => 'bruce',
 	29 => 'icedtea-web',
+	3 => 'ruby34-rgen',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
